.. _userdoc-concepts-explanations:

Concepts & explanations
=======================

This section provides the theory behind some of the most complex analysis modules and
explains the general design of MAICoS. Its purpose is to provide more clarity and
understanding of what MAICoS is all about.

.. toctree::
    :maxdepth: 1

    general-design
    dielectric
    saxs
    pdfs
